#[non_exhaustive]pub enum Error {
IoError(Error),
JsonError(Error),
Lock {
path: PathBuf,
source: Error,
},
Cleanup {
cleanup: Box<Error>,
original: Box<Error>,
},
}Expand description
The kinds of error that persisting a value to a file can produce.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IoError(Error)
An I/O operation on the file failed.
JsonError(Error)
The value could not be serialized to, or deserialized from, JSON.
Lock
The file could not be locked for exclusive access.
Cleanup
An operation failed, and so did the cleanup that followed it.